@@ -270,8 +270,8 @@ lmResp <-                               # base class for response modules
                         if (is.null(ll$y)) stop("y must be specified")
                         y <<- as.numeric(ll$y)
                         n <- length(y)
-                        mu <<- if (!is.null(ll$mu))
-                            as.numeric(ll$mu) else numeric(n)
+                        mu <<- if (!is.null(ll[["mu"]]))
+                            as.numeric(ll[["mu"]]) else numeric(n)
                         offset <<- if (!is.null(ll$offset))
                             as.numeric(ll$offset) else numeric(n)
                         weights <<- if (!is.null(ll$weights))
